consort: Create Consort diagram

consortR Documentation

Create Consort diagram

Description

To make it easy to create CONSORT diagrams for the transparent reporting of participant allocation in randomized, controlled clinical trials. This is done by creating a standardized disposition data, and using this data as the source for the creation a standard CONSORT diagram. Human effort by supplying text labels on the node can also be achieved.

Author(s)

Maintainer: Alim Dayim ad938@cam.ac.uk (ORCID)

See Also

Useful links:


consort documentation built on April 26, 2026, 9:06 a.m.