| connect_box | R Documentation |
This function is used to create an arrow line to connect two boxes. User should provide the starting and ending side of the arrow.
connect_box(
start,
end,
connect,
type = c("s", "p"),
name = NULL,
arrow_gp = consort_opt("arrow_gp"),
arrow_length = consort_opt("arrow_length"),
arrow_type = consort_opt("arrow_type")
)
start |
Starting point of the arrow. |
end |
Ending point of the arrow. |
connect |
The connection of the box. It should be the combination of the
position. The |
type |
Should be one the |
name |
A character identifier of the line grob, passed to |
arrow_gp |
Graphical parameters |
arrow_length |
Length of the arrowhead as a |
arrow_type |
Arrow type, either |
A lines grob with arrow.
fg1 <- textbox(text = "This is a test")
fg2 <- textbox(text = "This is an other test", 0.7, 0.2)
grid::grid.draw(fg1)
grid::grid.draw(fg2)
connect_box(fg1, fg2, connect = "bl", type = "p")
# Customize line width and color
connect_box(fg1, fg2, connect = "bl", type = "p", arrow_gp = grid::gpar(lwd = 2, col = "red"))
# Or set globally via set_consort_defaults
set_consort_defaults(arrow_gp = grid::gpar(lwd = 2, col = "blue"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.