gen_text: Generate label and bullet points

View source: R/gen_text.R

gen_textR Documentation

Generate label and bullet points

Description

This function use the data to generate label and bullet points for the box.

Usage

gen_text(x, label = NULL, bullet = FALSE, bullet_char = consort_opt("bullet"))

Arguments

x

A list or a vector to be used. x can be atomic vector, a data.frame or a list. A data.frame is particular useful if the there's a nested reason or a list split nested reasons by group. The nested reasons only support two columns and the bullet will be ignored.

label

A character string as a label at the beginning of the text label. The count for each categories will be returned if no label is provided.

bullet

If shows bullet points. If the value is TRUE, the bullet points will be tabulated, default is FALSE.

bullet_char

A single character used as the bullet symbol. Defaults to consort_opt("bullet"). Can be any Unicode character such as "\u2013" (en-dash), "\u25CB" (circle), "\u25A0" (square), "-", etc.

Value

A character string of vector.

Examples

val <- data.frame(
  am = factor(ifelse(mtcars$am == 1, "Automatic", "Manual"), ordered = TRUE),
  vs = factor(ifelse(mtcars$vs == 1, "Straight", "V-shaped"), ordered = TRUE),
  car = row.names(mtcars)
)

gen_text(val$car, label = "Cars in the data")
gen_text(val$car, label = "Cars in the data", bullet = FALSE)
gen_text(split(val$car, val$am), label = "Cars in the data")
gen_text(split(val$car, val$am), label = "Cars in the data", bullet = FALSE)
gen_text(split(val[,c("vs", "car")], val$am), label = "Cars in the data", bullet = FALSE)
gen_text(val[,c("vs", "car")], label = "Cars in the data", bullet = FALSE)

# Use a custom bullet character
gen_text(val$car, label = "Cars in the data", bullet = TRUE, bullet_char = "-")

# Or set globally via set_consort_defaults
set_consort_defaults(bullet = "\u25CB")
gen_text(val$car, label = "Cars in the data", bullet = TRUE)

consort documentation built on April 26, 2026, 9:06 a.m.